module.exports = defineTest({
	description: 'destructured parameters are properly renamed (#2418)'
});
